@@ -1,4 +1,4 @@
-package Pcore::Core::Log::Pipe::xmpp;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::Core::Log::Pipe::xmpp;
 
 use Pcore -class;
 
